1000 ' Lawson Labs, Inc.
1010 ' 3239 Phoenixville Pike
1020 ' Malvern, PA  19355                             www.lawsonlabs.com
1030 ' 610 725-8800 or 800 321-5355                      January 4, 1991
1040 '
1050 ' Instructions and sample driver for Model 96 DAC with Digital I/O
1060 '
1070 ' The Model 96 has up to 8 channels of 12-bit analog output.
1080 ' Up to half of them may be factory configured as current sink outputs.
1090 ' There are also 16 each digital inputs and outputs.
1100 ' Except for the buss interface circuitry, The Model 96 is powered by
1110 ' an external power supply. +/-12 to 15 volts and 5 volts are required.
1120 ' Each supply should have 250 MA available.
1130 ' Electrical isolation is provided by an optical barrier.
1140 '
1150 BAS% = 768' Change the address here if DIP switches 1, 2 & 3 are not ON.
1160 ' See below for a table of base addresses.
1170 ' An OUT instruction to the BAS% port sends 8-bit data to the Model 96.
1180 ' An INP instruction from the BAS% port returns data from the Model 96.
1190 ' The returned data is a single bit in the least significant location.
1200 CTRL% = BAS% + 1: 'This is the control register address.
1210 ' The three least significant bits control the card.
1220 ' The first bit latches the low word for the DACS.
1230 ' The first bit also selects for one of two 8-bit output words.
1240 ' The second bit updates the DACS.
1250 ' The third bit latches a digital output word.
1260 ' The control register is a write-only register
1270 OUT BAS%, 0: OUT CTRL%, 6' Initialize the registers
1280 ' Note that contol bits 2 & 4 are active low.
1290 ' Unless you are updating a dac or digital output, leave them high.
1300 '
1310  KEY OFF: CLS
1320  LOCATE 10, 20: PRINT "1)  Read digital inputs"
1330  LOCATE 12, 20: PRINT "2)  Set digital outputs"
1340  LOCATE 14, 20: PRINT "3)  Set analog outputs"
1350  LOCATE 16, 20: PRINT "4)  Exit"
1360  LOCATE 21, 20: PRINT "Enter the number of your choice."
1370 A$ = INPUT$(1): A = VAL(A$): CLS
1380 ON A GOSUB 1420, 1570, 1800, 1400
1390 GOTO 1310
1400 END
1410 '
1420 ' Read digital inputs
1430 ' Digital inputs can be contact closures to ground or TTL or 5 volt CMOS
1440 ' logic levels. Inputs are active low with 4.7K pull-up resistors.
1450 ' Inputs are protected against overvoltages of 50 VDC continuous.
1460 ' To read digital input N, first write N to the BAS% address.
1470 ' Next, read back the BAS% location and test the least significant bit.
1480 LOCATE 20, 20: PRINT "Press space to return to menu."
1490 LOCATE 1, 1
1500 FOR DIGINPUT% = 0 TO 15
1510 OUT BAS%, DIGINPUT%: GOSUB 2080' This is a short pause subroutine
1520 IF INP(BAS%) AND 1 THEN PRINT "OFF" ELSE PRINT "ON "
1530 NEXT DIGINPUT%
1540 LOCATE 1, 1
1550 IF INKEY$ = "" THEN 1490 ELSE RETURN
1560 '
1570 ' Set digital outputs
1580 ' Digital outputs are LSTTL logic levels. All outputs are reset to
1590 ' zero on power up. The 16 digital outputs are mapped as 2 8-bit words.
1600 INPUT "Enter output port number (0 or 1) or M for Menu "; A$
1610 IF A$ = "m" OR A$ = "M" THEN RETURN
1620 OUTPORT% = VAL(A$) MOD 2
1630 ' Port 0 contains outputs 0-7 and port 1 contains outputs 8-15
1640 PRINT "Enter output code for port"; OUTPORT%; : INPUT A$
1650 OUTCODE% = VAL(A$) MOD 256
1660 ' The digital output ports are each an 8-bit register.
1670 ' If a bit is zero, then the corresponding output will be low.
1680 ' First write the data to BAS%, then lower and raise control bit 3.
1690 ' If control bit 1 is high when bit 3 is raised, then port 1 will update.
1700 OUT BAS%, OUTCODE%: GOSUB 2080 ' This subroutine is a short delay only.
1710 OUT CTRL%, 6 + OUTPORT%: GOSUB 2080: OUT CTRL%, 2 + OUTPORT%: GOSUB 2080
1720 ' Lower control bit 3
1730 OUT CTRL%, 6 + OUTPORT%
1740 ' Raise bit 3 again
1750 ' The registers require about 350 microseconds settling time
1760 ' for the optical isolation. Fast languages will need the delay after
1770 ' each OUT CTRL% and OUT BAS% instruction.
1780 GOTO 1600
1790 '
1800 ' Set analog outputs
1810 ' A COUNT of zero produces the mimimum voltage out, the offset voltage.
1820 ' A dac COUNT of 4095 produces the fullscale voltage.
1830 ' VOLTS = (COUNT/4095) * (fullscale voltage - offset) + offset
1840 ' The current output channels produce a voltage between 0.4 and 2 volts.
1850 ' That voltage is converted to a current of 4 to 20MA.
1860 ' To update a voltage output:
1870 ' First the low byte of the output word is written to the BAS% address.
1880 ' The first control bit is raised to latch the low data byte.
1890 ' Then the high byte is multiplied by 16 to right-justify it.
1900 ' The justified high byte is added to the dac number and written.
1910 ' When the second control bit is dropped, the proper dac is selected.
1920 ' When the second control bit goes high, the dac updates.
1930 INPUT "Enter DAC number (0 to 7) or m for menu ", A$
1940 ' Max DAC number can be 1, 3, 5, or 7
1950 IF A$ = "m" OR A$ = "M" THEN RETURN
1960 DACNUM% = VAL(A$) MOD 8
1970 INPUT "Enter count (0-4095) ", A$: COUNT = VAL(A$) MOD 4096
1980 HIGHBYTE% = INT(COUNT / 256)
1990 LOWBYTE% = COUNT - (HIGHBYTE% * 256)
2000 OUT BAS%, LOWBYTE%: OUT CTRL%, 6: GOSUB 2080: OUT CTRL%, 7: GOSUB 2080
2010 ' Raising the first control bit latches the low data byte.
2020 OUT BAS%, DACNUM% + HIGHBYTE% * 16: GOSUB 2080
2030 ' The combination of highbyte and dac number is sent.
2040 OUT CTRL%, 4: GOSUB 2080: OUT CTRL%, 6
2050 ' lowering then raising the second control bit updates the dac.
2060 GOTO 1930
2070 '
2080 ' This gosub is a short pause to allow the opto-isolators to settle.
2090 ' The pause must be at least 350 microseconds.
2100 RETURN
2110 '
2120 '
2130 ' NOTES:
2140 '
2150 ' Base address selection   BAS%
2160 ' DIP SWITCH NUMBER        DECIMAL ADDRESS        HEX ADDRESS
2170 '   1     2     3
2180 '  ON    ON    ON               768                   300
2190 '  OFF   ON    ON               772                   304
2200 '  ON    OFF   ON               776                   308
2210 '  OFF   OFF   ON               780                   30C
2220 '  ON    ON    OFF              784                   310
2230 '  OFF   ON    OFF              788                   314
2240 '  ON    OFF   OFF              792                   318
2250 '  OFF   OFF   OFF              796                   31C
2260 '
2270 ' Switch 4 is not used.
2275 '
2280 ' Internal Adjustments
2290 '
2300 ' Each channel has its own gain and offset pots labeled G and O.
2310 ' Even channels are voltage output and odd channels may be current.
2320 ' To set a voltage channel, output a count of 0 and adjust the offset for
2330 ' zero volts out. Then output a count of 4095 and adjust the gain pot for
2340 ' the desired fullscale voltage. Then, re-adjust the offset pot.
2350 ' For a current (or voltage) channel, adjust the gain for the desired span
2360 ' by alternately reading the 0-count output and the 4095-count output
2370 ' and taking the difference. Then adjust the offset. The proceedure should
2380 ' be repeated for best accuracy.
2390 '
2400 '
2410 ' The current output is a current sink. A loop supply of 12 to 30 volts
2420 ' should be connected between the plus end of the load and the external
2430 ' ground. The minus end of the load goes to the channel output.
2440 '
2450 ' Pinout and cabling for Model 96
2460 '
2470 ' DB Connector pin numbers are different from ribbon cable positions.
2480 '
2490 '
2500 ' Ribbon Cable Position    DB Pin #       Signal Name
2510 '
2520 '           1                 1            Input 15
2530 '           2                34             +5 VDC
2540 '           3                18             +5 VDC
2550 '           4                 2            Input 14
2560 '           5                35             +15 VDC
2570 '           6                19             +15 VDC
2580 '           7                 3            Input 13
2590 '           8                36             -15 VDC
2600 '           9                20             -15 VDC
2610 '          10                 4            Input 12
2620 '          11                37          Analog Ground
2630 '          12                21          Digital Ground
2640 '          13                 5            Input 11
2650 '          14                38          4-20 MA Ground
2660 '          15                22          Digital Ground
2670 '          16                 6            Input 10
2680 '          17                39            Output 15
2690 '          18                23            Input  9
2700 '          19                 7            Input  8
2710 '          20                40            Output 14
2720 '          21                24            Input 7
2730 '          22                 8            Input 6
2740 '          23                41            Output 13
2750 '          24                25            Output 12
2760 '          25                 9            Input 5
2770 '          26                42            Output 11
2780 '          27                26            Output 10
2790 '          28                10            Input 4
2800 '          29                43            Output 9
2810 '          30                27            Output 8
2820 '          31                11            Input 3
2830 '          32                44            Output 7
2840 '          33                28            Output 6
2850 '          34                12            Input 2
2860 '          35                45            Output 5
2870 '          36                29            Output 4
2880 '          37                13            Input 1
2890 '          38                46            Output 3
2900 '          39                30            Output 2
2910 '          40                14            Input 0
2920 '          41                47            Output 1
2930 '          42                31            Output 0
2940 '          43                15            Analog 7
2950 '          44                48            Analog 4
2960 '          45                32            Analog 3
2970 '          46                16            Analog 6
2980 '          47                49            Analog 2
2990 '          48                33            Analog 1
3000 '          49                17            Analog 5
3010 '          50                50            Analog 0

